==========================
Welcome to networking-odl!
==========================

.. Team and repository tags

.. image:: http://governance.openstack.org/badges/networking-odl.svg
    :target: http://governance.openstack.org/reference/tags/index.html

.. Change things from this point on

Summary
-------

OpenStack networking-odl is a library of drivers and plugins that integrates
OpenStack Neutron API with OpenDaylight Backend. For example it has ML2
driver and L3 plugin to enable communication of OpenStack Neutron L2
and L3 resources API to OpenDayLight Backend.

To report and discover bugs in networking-odl the following
link can be used:
https://bugs.launchpad.net/networking-odl

Any new code submission or proposal must follow the development
guidelines detailed in HACKING.rst and for further details this
link can be checked:
https://docs.openstack.org/networking-odl/latest/

The OpenDaylight homepage:
https://www.opendaylight.org/

Release notes for the project can be found at:
https://docs.openstack.org/releasenotes/networking-odl/

The project source code repository is located at:
https://opendev.org/openstack/networking-odl
